==> haskell-tasty-hslua-1.1.1-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hslua
version:              1.1.1
visibility:           public
id:                   tasty-hslua-1.1.1-2HyyOTH3PCGIroI8m2Af71
key:                  tasty-hslua-1.1.1-2HyyOTH3PCGIroI8m2Af71
license:              MIT
copyright:            © 2017-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Tasty helpers to test HsLua.
description:
    Various tasty helpers and utilities to test HsLua
    oparations. Built on top of tasty-hunit.

category:             Foreign
abi:                  474ab5bdcf488d5fd2a3b43b98b270e0
exposed:              True
exposed-modules:      Test.Tasty.HsLua
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-hslua-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-hslua-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-hslua-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hslua
hs-libraries:         HStasty-hslua-1.1.1-2HyyOTH3PCGIroI8m2Af71
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-DSJU8SYKYU4DnTGKMQUYFy
    tasty-1.5-GipkZ3gZ4qmGz8Rl0ke00W
    tasty-hunit-0.10.2-DGY4K8h8x95Gq7nOanNqrP

haddock-interfaces:   /usr/share/doc/haskell-tasty-hslua/html/tasty-hslua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hslua/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hslua-1.1.1-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hslua
version:              1.1.1
visibility:           public
id:                   tasty-hslua-1.1.1-CqKEOm0smlfEmjqi1hwwHt
key:                  tasty-hslua-1.1.1-CqKEOm0smlfEmjqi1hwwHt
license:              MIT
copyright:            © 2017-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Tasty helpers to test HsLua.
description:
    Various tasty helpers and utilities to test HsLua
    oparations. Built on top of tasty-hunit.

category:             Foreign
abi:                  5b09ed60620f12d83fcab1442bc5756a
exposed:              True
exposed-modules:      Test.Tasty.HsLua
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-hslua-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-hslua-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-hslua-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hslua
hs-libraries:         HStasty-hslua-1.1.1-CqKEOm0smlfEmjqi1hwwHt
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-DCimRFrkPNqLRhEWBh8kjB
    tasty-1.5-HRKFxdWOFSUB4B7lvl4GhP
    tasty-hunit-0.10.2-I5CPkJTMq0iLGchqanJqmY

haddock-interfaces:   /usr/share/doc/haskell-tasty-hslua/html/tasty-hslua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hslua/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
